<?php


class Jeu extends Model {
   public $id, $nom, $description, $slug;

   public static function getFromSlug($slug_jeu) {
      $db = Database::getInstance();
      $sql = "SELECT * FROM R_jeu WHERE slug = :slug";
      $stmt = $db->prepare($sql);
      $stmt->setFetchMode(PDO::FETCH_CLASS, "Jeu"); // règle le type dans lequel on doit mettre les données (PDO va chercher les attributs de la classe de même nom que ses colonnes de BDD et mettre dedans les valeurs correspondantes)
      $stmt->execute(array(":slug" => $slug_jeu));
      return $stmt->fetch();
   }

   public static function getList() {
      $db = Database::getInstance();
      $sql = "SELECT * FROM R_jeu WHERE est_valide";
      $stmt = $db->query($sql);
      $stmt->setFetchMode(PDO::FETCH_CLASS, "Jeu");
      return $stmt->fetchAll();

   }


   public static function getMostPlayed() {
      $db = Database::getInstance();
      $sql = 'SELECT nom, slug, COUNT(*) as "parties" FROM R_partie JOIN R_jeu ON slug = jeu GROUP BY nom, r_jeu.slug ORDER BY parties DESC';
      $stmt = $db->query($sql);
	  $ret = array();
	  $k = 0;
	  while($k<3 && ($elt = $stmt->fetch())) {
		  echo $elt['nom'].'<br>';
		  $k++;
		  array_push($ret, $elt);
	  }
      return $ret;

   }
    
   public static function getSlugList() {
      $db = Database::getInstance();
      $sql = "SELECT slug FROM R_jeu";
      $stmt = $db->query($sql);
	  $return = array();
	  while($elt = $stmt->fetch()) {
		  array_push($return, $elt['slug']);
	  }
      return $return;
   }

   public static function checkExists($slug_jeu) { // méthode permettant de vérifier si un jeu existe dans la BDD
      $db = Database::getInstance(); // on récupère la connexion à la BDD
      $sql = "SELECT * FROM R_jeu WHERE slug = :slug";
      $req = $db->prepare($sql); // on prépare la requête
      $req->execute(array(":slug" => $slug_jeu)); // on remplace les variables dans la requête

      if($result = $req->fetch()) { // on récupère l'enregistrement, s'il existe
         return 1;
      }

      return 0; // on aurait pu mettre deux return (un dans le if et un ici), mais bon...
   }

   public static function checkExistsId($id) { // méthode permettant de vérifier si un jeu existe dans la BDD
      $db = Database::getInstance(); // on récupère la connexion à la BDD
      $sql = "SELECT * FROM R_jeu WHERE id = :id";
      $req = $db->prepare($sql); // on prépare la requête
      $req->execute(array(":id" => $id)); // on remplace les variables dans la requête

      if($result = $req->fetch()) { // on récupère l'enregistrement, s'il existe
         return 1;
      }

      return 0; // on aurait pu mettre deux return (un dans le if et un ici), mais bon...
   }

	public static function addRequest($nom_jeu, $description, $slug_jeu, $type, $type_scores, $min_joueurs, $max_joueurs=null, $min_equipes=null, $max_equipes=null) {
		$db = Database::getInstance();
		$sql = "INSERT INTO R_jeu (nom, description, slug, min_joueurs, max_joueurs, min_equipes, max_equipes, type, type_scores)
				VALUES (:nom, :description, :slug, :min_joueurs, :max_joueurs, :min_equipes, :max_equipes, :type, :type_scores);";
		$stmt = $db->prepare($sql);
		
		if($stmt->execute(array(":nom" => $nom_jeu, ":description" => $description, ":slug" => $slug_jeu, ":type" => Controller::slugify($type), ":type_scores" => Controller::slugify($type_scores), ":min_joueurs" => $min_joueurs, ":max_joueurs" => $max_joueurs, ":min_equipes" => $min_equipes, ":max_equipes" => $max_equipes))) {
			//ok
		}
		else {
			var_dump(array(":nom" => $nom_jeu, ":description" => $description, ":slug" => $slug_jeu, ":type" => $type, ":type_scores" => $type_scores, ":min_joueurs" => $min_joueurs, ":max_joueurs" => $max_joueurs, ":min_equipes" => $min_equipes, ":max_equipes" => $max_equipes));
			echo "Arise, ça marche pas..."; die();
		}
	}


    public static function getFromNom($nom_jeu)
    {
        $db = Database::getInstance();
        $sql = "SELECT * FROM R_jeu WHERE nom = :nom";
        $stmt = $db->prepare($sql);
        $stmt->setFetchMode(PDO::FETCH_CLASS, "Jeu"); // règle le type dans lequel on doit mettre les données (PDO va chercher les attributs de la classe de même nom que ses colonnes de BDD et mettre dedans les valeurs correspondantes)
        $stmt->execute(array(":nom" => $nom_jeu));
        return $stmt->fetch();
    }
    

    public static function checkExistsNom($nom)
    { // méthode permettant de vérifier si un jeu existe dans la BDD
        $db = Database::getInstance(); // on récupère la connexion à la BDD
        $sql = "SELECT * FROM R_jeu WHERE nom = :nom";
        $req = $db->prepare($sql); // on prépare la requête
        $req->execute(array(":nom" => $nom)); // on remplace les variables dans la requête

        if ($result = $req->fetch()) { // on récupère l'enregistrement, s'il existe
            return 1;
        }

        return 0; // on aurait pu mettre deux return (un dans le if et un ici), mais bon...
    }

}



